==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ProvidedOperationBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedOperationSetImpl;

import java.util.Arrays;
import java.util.List;


public class ProvidedOperationBodySetImpl extends InstanceSet<ProvidedOperationBodySet,ProvidedOperationBody> implements ProvidedOperationBodySet {

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( ProvidedOperationBody providedoperationbody : this ) providedoperationbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ProvidedOperationBody providedoperationbody : this ) providedoperationbody.setId( ref_Id );
    }


    // selections
    @Override
    public ProvidedOperationSet R687_specifies_processing_for_ProvidedOperation() throws XtumlException {
        ProvidedOperationSet providedoperationset = new ProvidedOperationSetImpl();
        for ( ProvidedOperationBody providedoperationbody : this ) providedoperationset.add( providedoperationbody.R687_specifies_processing_for_ProvidedOperation() );
        return providedoperationset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( ProvidedOperationBody providedoperationbody : this ) bodyset.add( providedoperationbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public ProvidedOperationBody nullElement() {
        return ProvidedOperationBodyImpl.EMPTY_PROVIDEDOPERATIONBODY;
    }

    @Override
    public ProvidedOperationBodySet emptySet() {
      return new ProvidedOperationBodySetImpl();
    }

    @Override
    public ProvidedOperationBodySet value() {
        return this;
    }

    @Override
    public List<ProvidedOperationBody> elements() {
        return Arrays.asList(toArray(new ProvidedOperationBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ProvidedOperationBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedOperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedOperationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ProvidedOperationBodySetImpl extends InstanceSet<ProvidedOperationBodySet,ProvidedOperationBody> implements ProvidedOperationBodySet {

    public ProvidedOperationBodySetImpl() {
    }

    public ProvidedOperationBodySetImpl(Comparator<? super ProvidedOperationBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( ProvidedOperationBody providedoperationbody : this ) providedoperationbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ProvidedOperationBody providedoperationbody : this ) providedoperationbody.setId( ref_Id );
    }


    // selections
    @Override
    public ProvidedOperationSet R687_specifies_processing_for_ProvidedOperation() throws XtumlException {
        ProvidedOperationSet providedoperationset = new ProvidedOperationSetImpl();
        for ( ProvidedOperationBody providedoperationbody : this ) providedoperationset.add( providedoperationbody.R687_specifies_processing_for_ProvidedOperation() );
        return providedoperationset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( ProvidedOperationBody providedoperationbody : this ) bodyset.add( providedoperationbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public ProvidedOperationBody nullElement() {
        return ProvidedOperationBodyImpl.EMPTY_PROVIDEDOPERATIONBODY;
    }

    @Override
    public ProvidedOperationBodySet emptySet() {
      return new ProvidedOperationBodySetImpl();
    }

    @Override
    public ProvidedOperationBodySet emptySet(Comparator<? super ProvidedOperationBody> comp) {
      return new ProvidedOperationBodySetImpl(comp);
    }

    @Override
    public ProvidedOperationBodySet value() {
        return this;
    }

    @Override
    public List<ProvidedOperationBody> elements() {
        return Arrays.asList(toArray(new ProvidedOperationBody[0]));
    }

}
